@@ -1,6 +1,6 @@
 from typing import Any
 
-from web_foundation.extentions.metrics.basemetric import BaseMetric
+from web_foundation.extentions.metrics.metric import Metric
 from web_foundation.extentions.metrics.exporter import MetricExporter
 from web_foundation.kernel.messaging.channel import IMessage
 
@@ -8,9 +8,9 @@ from web_foundation.kernel.messaging.channel import IMessage
 class NewMetricEvent(IMessage):
     message_type = "new_metric"
     destination = "__dispatcher__"
-    metric: BaseMetric
+    metric: Metric
 
-    def __init__(self, metric: BaseMetric):
+    def __init__(self, metric: Metric):
         super().__init__()
         self.metric = metric
 
@@ -18,7 +18,7 @@ class NewMetricEvent(IMessage):
         return f"NewMetricEvent({self.metric.__str__()})"
 
 
-class MetricRequest(IMessage):
+class MetricRequestEvent(IMessage):
     message_type = "metrics_request"
     destination = "__dispatcher__"
     exporter: MetricExporter
