@@ -14,6 +14,7 @@ class Dependency(Generic[T]):  # type: ignore
     def __init__(self, instance_of: Type[T] = None, default: T = None, **kwargs):
         self.instance_of = instance_of
         self.default = default
+        self._initialized = self._initialized
 
     def __call__(self, *args, **kwargs) -> T:
         if not self._initialized and not self.default:
@@ -27,3 +28,7 @@ class Dependency(Generic[T]):  # type: ignore
             raise AttributeError("Dependency must init with same instance as instance_of or nested cls")
         self._initialized = obj
         return self
+
+    @property
+    def initialized(self) -> T:
+        return self._initialized
