@@ -1,13 +1,12 @@
 import shutil
-from enum import Enum
 from pathlib import Path
-from typing import Type, TypeVar, Generic, Any, Generator
+from typing import Generator
 from aiofiles import os
 from aiofiles.os import wrap
 from aiofiles.threadpool import open
 from aiofiles.base import AiofilesContextManager
 
-from web_foundation.kernel.channel import IChannel
+from web_foundation.kernel.messaging.channel import IChannel
 from web_foundation.resources.files.interface import FilesResource
 
 rmtree = wrap(shutil.rmtree)
